CryptObject

Enum CryptObject 

pub enum CryptObject {
    Identifier(String),
    String(String),
    Body(CryptConfig),
    Null,
}
An ambiguously wrapped object in a crypt config.

crypt objects come in four variants: identifiers, string literals, bodies (nested configs), and nulls.

CryptObject implements TryInto for &String and &CryptConfig for quick conversions. More complex conversion methods are additionally implemented.

Variants



Identifier(String)



String(String)



Body(CryptConfig)



Null

Implementations

Source

impl CryptObject

pub fn unwrap_identifier(&self) -> &String

Unwraps an identifier crypt object into its String value

Panics

Panics if the crypt object is not an identifier. Unlike TryInto this will not automatically convert string literals.

pub fn expect_identifier(&self, msg: &str) -> &String

Unwraps an identifier crypt object into its String value

Panics

Panics if the crypt object is not an identifier with a special message given by msg. Unlike TryInto this will not automatically convert string literals.

pub fn unwrap_identifier_or<'a>(&'a self, other: &'a String) -> &'a String

Unwraps an identifier crypt object into its string value, alternatively if the object isn’t an identifier it will return the alternate string value.

pub fn unwrap_string(&self) -> &String

Unwraps a string literal crypt object into its String value

Panics

Panics if the crypt object is not an identifier. Unlike TryInto this will not automatically convert identifier.

pub fn expect_string(&self, msg: &str) -> &String

Unwraps a string literal crypt object into its String value

Panics

Panics if the crypt object is not an identifier with a special message given by msg. Unlike TryInto this will not automatically convert identifiers.

pub fn unwrap_string_or<'a>(&'a self, other: &'a String) -> &'a String

Unwraps a string literal crypt object into its string value, alternatively if the object isn’t a string literal it will return the alternate string value.

pub fn unwrap_nested_config(&self) -> &CryptConfig

Unwraps a string literal crypt object into its String value

Panics

Panics if the crypt object is not an identifier. Unlike TryInto this will not automatically convert identifier.

pub fn expect_nested_config(&self, msg: &str) -> &CryptConfig

Unwraps a string literal crypt object into its String value

Panics

Panics if the crypt object is not an identifier with a special message given by msg. Unlike TryInto this will not automatically convert identifiers.