CryptParserServer

Struct CryptParserServer 

pub struct CryptParserServer { /* private fields */ }
Sets up a parsing server for parsing crypt files.

Example

use crypt_config::{CryptParserServer, Cryptic};

#[derive(Cryptic)]
struct MyStruct {
    str: String
}

let mut server = CryptParserServer::new();
let my_struct: MyStruct = server.open("path/to/my/file.crypt").expect("Failed to parse file");

The parser will automatically convert the resulting crypt file into the desired Cryptic type.

Implementations

Source

impl CryptParserServer

pub fn new() -> Self

Creates a new parser server that can be reused while opening crypt files.

pub fn open<P, T>(&mut self, path: P) -> Result<T, CryptError>
where P: AsRef<Path>, T: Cryptic,

Opens a crypt file from a path and automatically converts it to the desired Cryptic type.