pub struct ListTagged<T, O> {
pub tags: Vec<T>,
pub object: O,
}Expand description
A custom tagged object parsed from a crypt file.
Fields
object: OTrait Implementations
Sourceimpl<T: Clone, O: Clone> Clone for ListTagged<T, O>
impl<T: Clone, O: Clone> Clone for ListTagged<T, O>
Sourcefn clone(&self) -> ListTagged<T, O>
fn clone(&self) -> ListTagged<T, O>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T, O> TryInto<ListTagged<T, O>> for TracedObject
impl<T, O> TryInto<ListTagged<T, O>> for TracedObject
Sourcetype Error = CryptError
type Error = CryptError
The type returned in the event of a conversion error.