TracedObject

Struct TracedObject 

pub struct TracedObject { /* private fields */ }
An object parsed from a crypt file that also contains debug information in the case of an error.

This is the main interface type for building Cryptic objects. Traced objects can be easily cast to other types while also providing debug information. If you need to handle ambiguous types use CrypticObject which strips away the added debug information.