Cryptic

Trait Cryptic 

pub trait Cryptic: Sized {
    // Required method
    fn cryptic(object: TracedObject) -> Result<Self, CryptError>;
}
An object that can be parsed from a crypt file.

A derive macro exists for this type and is expected to be used over manually implementing it.

Required Methods

fn cryptic(object: TracedObject) -> Result<Self, CryptError>

Attempts to convert an AST from a crypt file into a desired type.

In most cases it is recommended to use CryptParserServer which will automatically call this method an opened file.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> Cryptic for Option<T>
where T: Cryptic,

Implementors