Crypt Configuration
Created 7/25/2026 - Nyx
A modern readable file format.
Crypt files are similar to json with additional support for enums special tags, identifiers, and includes. Crypt is essentially a superset of json meaning any json file can parsed as if it was a crypt file.
Using the beauty of Rust crypt files can be parsed directly into rust native structs and enums using the Cryptic derivation. To parse a crypt file a CryptParserServer is used which automatically caches opened files and reuses them when requested.
Structs
- Crypt
Error - An error that can happen during the parsing and building of crypt files.
- Crypt
Parser Server - Sets up a parsing server for parsing crypt files.
- Hash
Tagged - A custom tagged object parsed from a crypt file.
- List
Tagged - A custom tagged object parsed from a crypt file.
- Tagged
- A custom tagged object parsed from a crypt file.
- Traced
Object - An object parsed from a crypt file that also contains debug information in the case of an error.
Enums
- Cryptic
Object - An ambiguous object parsed from a crypt file.
Traits
- Cryptic
- An object that can be parsed from a crypt file.
Derive Macros
- Cryptic
- Allows structs and enums to automatically be constructed from a parsed crypt file.