pub struct CryptConfig { /* private fields */ }Expand description
A Crypt Configuration object
Uses a simple map for string identifiers to CryptObjects. Configs can contain other nested configs, string literals, and identifiers. String literals and identifiers are both stored as a String.
Example
Example crypt file:
./tests/test.crypt
version = "0.1.0";
name = "Test";
type = "Executable"Opening the file:
use crypt_configs::{open_config, body::CryptObject};
let config = match open_config("tests/test.crypt") {
Ok(c) => c,
Err(e) => panic!("Failed to open test file!"),
};
assert_eq!(config.get("version").unwrap().try_into(), Ok(&String::from("0.1.0")));
assert_eq!(config.get("name").unwrap().try_into(), Ok(&String::from("Test")));
assert_eq!(config.get("type").unwrap().try_into(), Ok(&String::from("Executable")));Implementations
Sourceimpl CryptConfig
impl CryptConfig
Sourcepub fn get<S>(&self, ident: S) -> Option<&CryptObject>
pub fn get<S>(&self, ident: S) -> Option<&CryptObject>
Retrieves an item from the config
The object is ambiguously wrapped in a CryptObject.