pub enum CrypticObject {
ConstantString(String),
ConstantInteger(i64),
ConstantFloat(f64),
ConstantBoolean(bool),
Null,
FloatingIdentifier(String),
IdentifiedObject(String, Box<CrypticObject>),
TaggedObject(Vec<CrypticObject>, Box<CrypticObject>),
ObjectBody(HashMap<String, CrypticObject>),
ObjectList(Vec<CrypticObject>),
}Expand description
An ambiguous object parsed from a crypt file.
This should only be used if the object you want parsed is expected to be multiple different types and should be handled manually. In any other case simply using that type is preferred.
Variants
ConstantString(String)
ConstantInteger(i64)
ConstantFloat(f64)
ConstantBoolean(bool)
Null
FloatingIdentifier(String)
IdentifiedObject(String, Box<CrypticObject>)
TaggedObject(Vec<CrypticObject>, Box<CrypticObject>)
ObjectBody(HashMap<String, CrypticObject>)
ObjectList(Vec<CrypticObject>)