pub struct CryptParserServer { /* private fields */ }Expand description
Sets up a parsing server for parsing crypt files.
Example
use crypt_config::{CryptParserServer, Cryptic};
#[derive(Cryptic)]
struct MyStruct {
str: String
}
let mut server = CryptParserServer::new();
let my_struct: MyStruct = server.open("path/to/my/file.crypt").expect("Failed to parse file");The parser will automatically convert the resulting crypt file into the desired Cryptic type.
Implementations